; ##############################################################################
; ##############################################################################
; ##############################################################################
;																			
; Timer1 (16Bit ) Vorteiler 												
;																			
; TCCR1B ==> ICNC1 ICES1 RESERVIERT WGM13 WGM12 CS12 CS11 CS10 				
;																			
;CS12 CS11 CS10 Description													
;	0	0 	0 	No clock source. (Timer/Counter stopped)					
;	0 	0 	1 	clkI/O/1    (No prescaling)									
;	0 	1 	0 	clkI/O/8    (From prescaler)								
; *	0 	1 	1 	clkI/O/64   (From prescaler)								
; 	1 	0 	0 	clkI/O/256  (From prescaler)								
; 	1 	0 	1 	clkI/O/1024 (From prescaler)								
;	1 	1 	0 	External clock source on T1 pin. Clock on falling edge.		
;	1 	1 	1 	External clock source on T1 pin. Clock on rising edge.		
;																			
TIMER1_INITIALISIERUNG:
	ldi temp,(0<<CS12)|(1<<CS11) |(1<<CS10)
	out TCCR1B,temp          
	; Timer 1 Startwert 	
	ldi temp,HIGH(TIMERWERT1)
	out tcnt1H,temp         
	ldi temp,LOW (TIMERWERT1) 
	out tcnt1L,temp     
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; Timer 0+1+2 berlauf-Int aktivieren (Timer/Counter Interrupt Mask)		
;																			
; TIMSK ==> OCIE2 TOIE2 TICIE1 OCIE1A OCIE1B TOIE1 R TOIE0  				
;																			
TIMER_AKTIVIEREN:
	ldi temp,(0<<OCIE2)|(0<<TOIE2)|(0<<TICIE1)|(0<<OCIE1A)|(0<<OCIE1B)|(1<<TOIE1)|(0<<TOIE0)
	out TIMSK,temp   
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 1ms 																			
TIM1_OVF:
	push TEMP		    ; Sichern von "TEMP" im Stack
	in	 TEMP,SREG		; Einlesen des SREG 
	push TEMP	    	; Schreiben von  SREG  im Stack (KOPIE)
	push TEMP1
	push TEMP2
	push TEMP3
	push ZL
	push ZH
; ----------------------------------
; Timer Startwert	 				
	ldi temp,HIGH(TIMERWERT1)
	out tcnt1H,temp         
	ldi temp,LOW (TIMERWERT1) 
	out tcnt1L,temp
; ----------------------------------
; Vorteiler 10:1					
VORTEILER:
	LDS temp,(adr_ssVT)		; aus SRAM laden			
	inc temp				; +1						
	cpi temp,10				; vergleich					
	brsh VORTEILER_w		; ist gleich oder grer	
	STS (adr_ssVT),temp		; in SRAM speichern			
	rjmp VORTEILER_ENDE	
; ----------------------------------
VORTEILER_w:
	STS (adr_ssVT),NULL		; in SRAM speichern			
	; ZEIT				
	rcall ZEIT
	; DCF-UHR			
	rcall DCF
	; PROGRAMMFREIGABE	
	LDS temp,(adr_10ms)	
	brne VORTEILER_ENDE
	LDS temp,(adr_ss)	
	brne VORTEILER_ENDE
	STS(adr_FREIGABE_PROGRAMM),EINS
; ----------------------------------
VORTEILER_ENDE:
	; DIGIT				
	rcall DIGIT
; ----------------------------------
	pop ZH
	pop ZL
	pop TEMP3
	pop TEMP2
	pop TEMP1
	pop	TEMP			; LESEN von SREG vom STACK (KOPIE)
	out	SREG,TEMP		; Wiederherstellen von SREG
	pop	TEMP			; Wiederherstellen von "TEMP" 				
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
; 10ms 																			
ZEIT:
	LDS temp,(adr_10ms)					; aus SRAM laden			
	inc temp							; +1						
	cpi temp,100						; vergleich mit 100			
	brsh ZEIT_SS						; ist gleich oder grer	
	STS (adr_10ms),temp					; in SRAM speichern			
	ret									; zurck					
ZEIT_SS:
	STS(adr_10ms),NULL					; NULL in SRAM speichern	

	LDS temp,(adr_ss)	; aus SRAM laden	
	inc temp
	cpi temp,60
	brsh ZEIT_MM
	STS (adr_ss),temp	; in SRAM speichern	
	ret	
ZEIT_MM:
	STS (adr_ss),NULL	; in SRAM speichern	

	LDS temp,(adr_mm)	; aus SRAM laden	
	inc temp
	cpi temp,60
	brsh ZEIT_HH
	STS (adr_mm),temp	; in SRAM speichern	
	ret	
ZEIT_HH:
	STS (adr_mm),NULL	; in SRAM speichern	

	LDS temp,(adr_hh)	; aus SRAM laden	
	inc temp
	cpi temp,24
	brsh ZEIT_TAG
	STS (adr_hh),temp	; in SRAM speichern	
	ret	
ZEIT_TAG:
	STS (adr_hh),NULL	; in SRAM speichern	

; WOCHENTAG				
	LDS temp,(adr_WOCHENTAG)
	inc temp
	cpi temp,7+1
	brlo ZEIT_WOCHENTAG_w
	ldi temp,1
ZEIT_WOCHENTAG_w:
	STS (adr_WOCHENTAG),temp

	LDS temp,(adr_TAG)	; aus SRAM laden	
	inc temp
	STS (adr_TAG),temp	; in SRAM speichern	
	
	rcall ZEIT_TAGE_IM_MONAT
	cp temp,temp1 
	brsh ZEIT_MONAT
	ret
; MONAT					
ZEIT_MONAT:
	STS (adr_TAG),EINS

	LDS temp,(adr_MONAT); aus SRAM laden	
	inc temp
	cpi temp,13 
	brsh ZEIT_JAHR
	STS (adr_MONAT),temp; in SRAM speichern	
	ret
; JAHR					
ZEIT_JAHR:
	STS (adr_MONAT),EINS

	LDS temp,(adr_JAHR)	; aus SRAM laden	
	inc temp
	STS (adr_JAHR),temp	; in SRAM speichern	
ret
; ##############################################################################
; Anzahl der TAGE im Monat	
ZEIT_TAGE_IM_MONAT:
	LDS temp1,(adr_MONAT)
	; vergleich	
	cpi temp1,2			; Februar 28 	
	breq ZEIT_TAGE_IM_MONAT_28
	cpi temp1,4			; April 30		
	breq ZEIT_TAGE_IM_MONAT_30
	cpi temp1,6			; Juni 30		
	breq ZEIT_TAGE_IM_MONAT_30
	cpi temp1,8			; August 31		
	breq ZEIT_TAGE_IM_MONAT_31
	cpi temp1,9			; September 30	
	breq ZEIT_TAGE_IM_MONAT_30
	cpi temp1,11		; November 30	
	breq ZEIT_TAGE_IM_MONAT_30
ZEIT_TAGE_IM_MONAT_31:
	ldi temp1,31
ret
ZEIT_TAGE_IM_MONAT_28:
	; Jahr laden					
	LDS temp1,(adr_JAHR)
	; SCHKEIFE						
ZEIT_TAGE_IM_MONAT_28s:
	; -4							
	subi temp1,4
	; vergleich						
	tst temp1
	; NULL=Schaltjahr				
	breq ZEIT_TAGE_IM_MONAT_29
	brpl ZEIT_TAGE_IM_MONAT_28s
	; negativ kein Schaltjahr		
	ldi temp1,28
	ret
ZEIT_TAGE_IM_MONAT_29:
	ldi temp1,29
	ret
ZEIT_TAGE_IM_MONAT_30:
	ldi temp1,30
	ret
; ##############################################################################
; ##############################################################################
; ##############################################################################



